#!/usr/bin/env bash
# backup.sh
# Worker script for Macup
# 29.10.08 filipp@lepalaan.org

RSYNC=$1; DST=$2

MYNAME="macup"
RESDIR=$(dirname $(dirname $0))
ICON="${RESDIR}/macup.tif"

COOKIE="/private/tmp/${MYNAME}.pid"
EXCLUDE=/private/tmp/macup.exclude.txt
INCLUDE=/private/tmp/macup.include.txt
MDFIND="/usr/bin/mdfind -onlyin ${HOME} "

OPTS="-raNHAXx --protect-args --fileflags --force-change --delete"
GROWL="${RESDIR}/bin/growlnotify --image ${ICON} -t ${MYNAME} -m "
MAC=$(ifconfig en0 ether | grep ether | awk '{print $2}' | sed 's/://g')

if [[ -e ${COOKIE} ]]; then
	$GROWL "Backup already in progress"
	exit 1
fi

logger "$MYNAME: starting backup..."

if [[ ${mdutil -s / | grep -c enabled} = 0 ]]; then
	logger "${MYNAME}: Spotlight must be enabled on the source volume"
	exit 1
fi

# let user know something's happening
$GROWL "Starting backup..."

touch $COOKIE

# collect the list of stuff to back up
$MDFIND kMDItemFSLabel=3 > $INCLUDE
mdfind -s ${MYNAME} | grep -v .savedSearch >> $INCLUDE
$MDFIND kMDItemFSLabel=1 > $EXCLUDE

# rsync - the best a man can get.
$RSYNC $OPTS --files-from=${INCLUDE} --exclude-from=${EXCLUDE} / "${DST}/${MAC}" >/dev/null &2>&1

logger "${MYNAME}: backup complete..."
$GROWL "Backup complete!"

srm $EXCLUDE $INCLUDE $COOKIE

exit 0